/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2014 Frederik Heber. All rights reserved.
 *
 *
 *   This file is part of MoleCuilder.
 *
 *    MoleCuilder is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    MoleCuilder is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MoleCuilder.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * Value_molecule.cpp
 *
 *  Created on: Sep 11, 2014
 *      Author: heber
 */

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include "Value_molecule.hpp"

#include "molecule.hpp"
#include "World.hpp"

static const molecule * FindMoleculeByName(const std::string &_name)
{
  const molecule * _mol = NULL;
  const vector<molecule *> molecules = World::getInstance().getAllMolecules();
  for (vector<molecule *>::const_iterator moliter = molecules.begin();
      moliter != molecules.end(); ++moliter) {
    if ((*moliter)->getName() == _name) {
      _mol = *moliter;
      break;
    }
  }
  return _mol;
}

template <>
bool Value<const molecule *>::isValidAsString(const std::string &_value) const throw(ParameterValidatorException)
{
  return (FindMoleculeByName(_value) != NULL);
}

template <>
const std::string Value<const molecule *>::getAsString() const throw(ParameterValueException)
{
  return get()->getName();
}

template <>
void Value<const molecule *>::setAsString(const std::string &_value) throw(ParameterException)
{
  const molecule * temp = FindMoleculeByName(_value);
  if (temp != NULL)
    set(temp);
}


